@@ -2,13 +2,16 @@
 
 import functools
 from types import MethodType
-from typing import Callable
+from typing import Any, Callable, Tuple, TypeVar
 
 import jax
 
 from .base import BaseModule
 from .threading_local import allow_mutation
 
+T = TypeVar("T")
+O = TypeVar("O")
+
 
 def pure(func: Callable):
     """Make a function pure by copying the inputs.
@@ -61,17 +64,29 @@ def pure(func: Callable):
             raise ValueError("Not supported")
 
         args, kwargs = _copy((args, kwargs))
-        modules = _get_all_submodules((args, kwargs))
+        modules = get_all_submodules((args, kwargs))
         with allow_mutation(modules):
             out = unbound_func(*args, **kwargs)
 
-        for m in _get_modules(out):
-            m.scan_bugs()
+            for m in modules:
+                m.find_and_register_pytree_attributes()
+                m.scan_bugs()
         return out
 
     return wrapper
 
 
+@pure
+def purecall(module: Callable[..., O], *args, **kwargs) -> Tuple[Any, O]:
+    """Call a module and return the updated module.
+
+    A shortcut for `pax.pure(lambda f, x: [f, f(x)])`.
+    """
+    assert isinstance(module, BaseModule)
+    assert callable(module)
+    return module, module(*args, **kwargs)
+
+
 def _get_modules(tree):
     "Return a list of modules in the pytree `tree`."
     modules = jax.tree_flatten(tree, is_leaf=lambda x: isinstance(x, BaseModule))[0]
@@ -79,14 +94,14 @@ def _get_modules(tree):
     return modules
 
 
-def _get_all_submodules(value):
+def get_all_submodules(value):
     submods = _get_modules(value)
     out = list(submods)
     for mod in submods:
-        out.extend(_get_all_submodules(mod.submodules()))
+        out.extend(get_all_submodules(mod.submodules()))
     return out
 
 
-def _copy(value):
+def _copy(value: T) -> T:
     leaves, treedef = jax.tree_flatten(value)
     return jax.tree_unflatten(treedef, leaves)
