@@ -1,9 +1,9 @@
 """Public utility functions."""
 
-from pax._src.utils import build_update_fn, grad_parameters, scan
+from pax._src.utils import build_update_fn, grad, scan
 
 __all__ = (
     "build_update_fn",
-    "grad_parameters",
+    "grad",
     "scan",
 )
